#!/usr/bin/env bash

usage()
{
cat << EOF
DESCRIPTION:
  Script for preparing solr indexes.
  
USAGE: 
  $0 SOLR_SERVER_URL INDEX_CORE_BASE_NAME INDEX_CORE_NAMES

EXAMPLE:
  $0 http://localhost:8983/solr comac- "doc;contr"

ARGUMENTS:
  SOLR_SERVER_URL         - Solr server URL 
  INDEX_CORE_BASE_NAME    - base name of the core        
  INDEX_CORE_NAMES        - names of the cores (separated by ";")

EOF
}

# function that creates full core name 
# function arguments:
#  $1 - base core name, 
#  $2 - core name, 
#  $3 - tmp suffix, 
#  $4 - number of tmp core
getFullCoreName(){
 fullCoreName=$1$2
 echo $fullCoreName
}

# function that prepares core 
# function arguments:
#  $1 - solr server url, 
#  $2 - full core name, 
prepareCore(){
curl $1/$2/update -H "Content-type: text/xml" --data-binary '<delete><query>*:*</query></delete>' && \
curl $1/$2/update -H "Content-type: text/xml" --data-binary '<commit />' && \
curl "$1/admin/cores?action=RELOAD&core=$2"
status=$?
if [ "$status" -ne "0" ]
then
exit $status
fi
}


if [ "${#@}" -lt "3" ]
then
usage
exit
fi

coreNames=(${3//;/ })

for coreName in "${coreNames[@]}"
do
prepareCore $1 $(getFullCoreName $2 $coreName)
done